# API

```{eval-rst}
.. module:: treedata
```

The central class:

```{eval-rst}
.. autosummary::
   :toctree: generated/

   TreeData
```

## Combining

Combining TreeData objects:

```{eval-rst}
.. autosummary::
   :toctree: generated/

   concat
```

## Read

Reading TreeData objects:

```{eval-rst}
.. autosummary::
   :toctree: generated/

   read_h5td
   read_zarr
```

## Write

Writing TreeData objects:

```{eval-rst}
.. autosummary::
   :toctree: generated/

   TreeData.write_h5td
   TreeData.write_zarr
```
